// Copyright (C) 1997, 1998 by DI Wolfgang Platzer, IAIK
// email: wplatzer@iaik.tu-graz.ac.at
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
// OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
// LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
// OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
// SUCH DAMAGE.
//

package iaik.jigsaw.https;

import java.io.* ;
import java.util.* ;

import org.w3c.tools.resources.*;
import org.w3c.jigsaw.http.socket.SSLSocketClientFactory;
import org.w3c.jigsaw.config.*;
import org.w3c.jigsaw.http.*;

/**
 * A wrapper class to give access to editable properties through a resource.
 * This class allows to reuse entirely the generic resource editor to
 * edit the properties of the server.
 */
public class SSLPropertySet extends PropertySet {

  private static String title = "SSL v3.0 properties";

  static {
  	Class     c = null;
	  Attribute a = null;

  	try {
	    c = Class.forName("iaik.jigsaw.https.SSLPropertySet");
  	} catch (Exception ex) {
	    ex.printStackTrace();
	    System.exit(1);
  	}

  	a = new BooleanAttribute(SSLSocketClientFactory.CLIENT_AUTHENTICATION_P
  				 , null
  				 , Attribute.EDITABLE);
  	AttributeRegistry.registerAttribute(c, a);

  	a = new BooleanAttribute(SSLSocketClientFactory.CLIENT_REQUIRE_CERTIFICATE_P
  				 , null
  				 , Attribute.EDITABLE);
  	AttributeRegistry.registerAttribute(c, a);

  	a = new BooleanAttribute(SSLSocketClientFactory.CLIENT_REQUIRE_TRUSTED_ROOT_P
  				 , null
  				 , Attribute.EDITABLE);
  	AttributeRegistry.registerAttribute(c, a);

  	a = new StringAttribute(SSLSocketClientFactory.TRUSTET_SIGNERS_P
  				 , null
  				 , Attribute.EDITABLE);
  	AttributeRegistry.registerAttribute(c, a);

  	a = new StringAttribute(SSLSocketClientFactory.RSA_KEY_AND_CERTIFICATE_P
  				 , null
  				 , Attribute.EDITABLE);
  	AttributeRegistry.registerAttribute(c, a);

  	a = new StringAttribute(SSLSocketClientFactory.DSA_KEY_AND_CERTIFICATE_P
  				 , null
  				 , Attribute.EDITABLE);
  	AttributeRegistry.registerAttribute(c, a);

  	a = new StringAttribute(SSLSocketClientFactory.DH_KEY_AND_CERTIFICATE_P
  				 , null
  				 , Attribute.EDITABLE);
  	AttributeRegistry.registerAttribute(c, a);
/*
  	a = new StringAttribute(SSLSocketClientFactory.TEMP_RSA_KEY_P
  				 , null
  				 , Attribute.EDITABLE);
  	AttributeRegistry.registerAttribute(c, a);

  	a = new StringAttribute(SSLSocketClientFactory.DH_PARAMETERS_P
  				 , null
  				 , Attribute.EDITABLE);
  	AttributeRegistry.registerAttribute(c, a);
*/
    for (int i=0; i<SSLSocketClientFactory.CIPHER_SUITES.length; i++) {
    	a = new BooleanAttribute((String)SSLSocketClientFactory.CIPHER_SUITES[i][0]
    				 , null
    				 , Attribute.EDITABLE);
    	AttributeRegistry.registerAttribute(c, a);
    }
  }

  /**
   * Get this property set title.
   * @return A String encoded title.
   */
  public String getTitle() {
  	return title;
  }

  public SSLPropertySet(String name, httpd server) {
  	super(name, server);
  }
}

